package io;

import java.io.*;

/**
 * A class that can be used to read/write objects
 * from/to the file system in line-oriented, 
 * comma-separated-valued (CSV) format.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class CSVFileProcessor extends FileProcessor {

    /**
     * Explicit Value Constructor.
     * 
     * @param file The File to use
     */
    public CSVFileProcessor(File file) {
        super(file);
    }

    /**
     * Explicit Value Constructor.
     * 
     * @param identifier The FileIdentifier to use
     */
    public CSVFileProcessor(FileIdentifier identifier) {
        super(identifier);
    }

    /**
     * Explicit Value Constructor.
     * 
     * @param fileName The fileName to use
     */
    public CSVFileProcessor(String fileName) {
        super(fileName);
    }

    /**
     * Decrypt a line in the file.
     * 
     * @param line The line to decrypt
     * @return The decryption (i.e., the plain text)
     */
    @Override
    protected String decrypt(String line) {
        return line;
    }

    /**
     * Encrypt a line in the file.
     * 
     * @param line The line to encrypt
     * @return The encryption
     */
    @Override
    protected String encrypt(String line) {
        return line;
    }

    /**
     * Read the CSV representations of objects from the file system.
     * 
     * @param objects The objects to populate
     * @throws IOException If something goes wrong
     */
    public void read(CSVRepresentable... objects) throws IOException {

        String[] lines;

        lines = super.readLines();
        for (int i=0; i<lines.length; i++) objects[i].fromCSV(lines[i]);
    }

    /**
     * Write the CSV representation of objects to the file system.
     * 
     * @param objects The objects to write
     * @throws IOException If something goes wrong
     */
    public void write(CSVRepresentable... objects) throws IOException {

        String[] lines;

        lines = new String[objects.length];
        for (int i=0; i<objects.length; i++) lines[i] = objects[i].toCSV();
        super.writeLines(lines);
    }
}
