package io;

import java.util.StringTokenizer;

/**
 * An encapsulation of a two-part (i.e., name and extension) file identifier.
 * 
 * @author CS159 Professors,  James Madison University
 * @version 1
 */
public class FileIdentifier implements CSVRepresentable {

    private String extension, name;

    /**
     * Explicit Value Constructor.
     * 
     * @param name The name (i.e., the part to the left of the dot)
     * @param extension (i.e., the part to the right of the dot)
     */
    public FileIdentifier(String name, String extension) {
        this.extension = extension;
        this.name = name;
    }


    /**
     * Populate the attributes of this Object from a CSV representation.
     * 
     * @param s The CSV representation
     * @return The object that was used to tokenize the CSV representation
     */
    @Override
    // They can choose between StringTokenizer and Scanner
    public StringTokenizer fromCSV(String s) {
        StringTokenizer st;
        st = new StringTokenizer(s, ",");
        name = st.nextToken();
        extension = st.nextToken();

        return st;
    }

    /**
     * Create a CSV representation of this Object.
     * 
     * @return The CSV representation
     */
    @Override
    public String toCSV() {
        return String.format("%s,%s", name, extension);
    }

    /**
     * Create a String representation of this FieldIdentifier.
     * 
     * @return The String representation
     */
    @Override
    public String toString() {
        return String.format("%s.%s", name, extension);
    }
}
