package io;

import java.io.*;

/**
 * An abstract encapsulation of an object that can read from and 
 * write to the file system in a line-oriented way.
 * 
 * This class supports encryption and decryption, but those
 * capabilities must be provided by the derived class.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public abstract class FileProcessor {

    private File file;


    /**
     * Explicit Value Constructor.
     * 
     * @param file The File to use
     */
    public FileProcessor(File file) {
        this.file = file;
    }

    /**
     * Explicit Value Constructor.
     * 
     * @param identifier The FileIdentifier to use
     */
    public FileProcessor(FileIdentifier identifier) {
        this(identifier.toString());
    }

    /**
     * Explicit Value Constructor.
     * 
     * @param fileName The fileName to use
     */
    public FileProcessor(String fileName) {
        this(new File(fileName));
    }

    /**
     * Decrypt a line in the file.
     * 
     * @param line The line to decrypt
     * @return The decryption (i.e., the plain text)
     */
    protected abstract String decrypt(String line);

    /**
     * Encrypt a line in the file.
     * 
     * @param line The line to encrypt
     * @return The encryption
     */
    protected abstract String encrypt(String line);

    /**
     * Read the lines in the file.
     * 
     * @return The lines
     * @throws IOException If something goes wrong
     */
    protected String[] readLines() throws IOException {

        BufferedReader in;
        int n;
        String s;
        String[] result;

        in = new BufferedReader(new FileReader(file));
        s = in.readLine();
        n = Integer.parseInt(s);
        result = new String[n];

        for (int i=0; i<n; i++) result[i] = decrypt(in.readLine());

        in.close();

        return result;
    }

    /**
     * Write lines to a file.
     * 
     * @param lines The lines to write
     * @throws IOException If something goes wrong
     */
    protected void writeLines(String[] lines) throws IOException {

        PrintWriter out;

        out = new PrintWriter(file);
        out.println(lines.length);
        for (int i=0; i<lines.length; i++) out.println(encrypt(lines[i]));

        out.close();
    }
}
