package membership;

import java.util.*;

/**
 * An encapsulation of an "exclusive" membership account at Big Box Bargains.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class VIPAccount extends Account {

    private int visits;

    /**
     * Default Constructor.
     * 
     * Constructs a VIPccount with 0 purchases, 0 credits used, and 0 visits.
     */
    public VIPAccount() {
        this(0.00, 0.00, 0);
    }

    /**
     * Explicit Value Constructor.
     * 
     * @param purchases The dollar amount of purchases
     * @param creditsUsed The dollar amount of credits used
     * @param visits The number of visits
     */
    public VIPAccount(double purchases, double creditsUsed, int visits) {
        super(purchases, creditsUsed);
        this.visits = visits;
    }

    /**
     * Returns true if this VIPAccount entitles the member to use the express
     * line at the store.
     * 
     * This method overrides the version in the Account class because the number
     * of visits can matter for VIPAccount holders, even if they have not
     * satisfied the condition for other reasons.
     * 
     * @return true if entitled; false otherwise
     */
    @Override
    public boolean canUseExpressLine() {
        return super.canUseExpressLine() || visits >= 10;
    }

    /**
     * Get the reward percentage (i.e., the percentage of the Account holder's
     * purchases that they are credited with).
     * 
     * @return The reward percentage
     */
    @Override
    public double getRewardPercentage() {
        double result, vipBonus;

        vipBonus = (visits / 10) * 0.01;
        result = Math.min(super.getRewardPercentage() + vipBonus, 0.15);
        return result;
    }

    /**
     * Get the number of visits this VIPAccount holder has made.
     * 
     * @return The number of visits
     */
    public int getVisits() {
        return visits;
    }

    /**
     * Increase the purchases by the given amount.
     * 
     * @param amount The amount of the increase
     */
    @Override
    protected void increasePurchases(double amount) {
        super.increasePurchases(amount);
        visits++;
    }

    /**
     * Populate the attributes of this VIPAccount from a CSV representation.
     * 
     * @param s The CSV representation
     * @return The object that was used to tokenize the CSV representation
     */
    @Override
    public StringTokenizer fromCSV(String s) {
        StringTokenizer st;
        st = super.fromCSV(s);
        this.visits = Integer.parseInt(st.nextToken());
        return st;
    }

    /**
     * Create a CSV representation of this VIPAccount object.
     * 
     * @return The CSV representation
     */
    @Override
    public String toCSV() {
        return String.format("%s,%d", super.toCSV(), visits);
    }

    /**
     * Create a String representation of this Account object.
     * 
     * @return The String representation
     */
    @Override
    public String toString() {
        return String.format("%s\nVisits: %d", super.toString(), getVisits());
    }
}
